Method: Rhoconnect::TestMethods#test_schema

Defined in:
lib/rhoconnect/test_methods.rb

#test_schemaObject

Executes the adapter’s schema method and returns the schema stored in redis For example, if your source adapter schema method was: def schema {

'version' => '1.0',
'property' => {
  'name' => 'string',
  'brand' => 'string',
  'price' => 'string',
  'image_url_cropped' => 'blob,overwrite',
  'image_url' => 'blob'
 },
'index' => {
  'by_name_brand' => 'name,brand'
},
'unique_index' => {
  'by_price' => 'price'
}

}.to_json test_schema would return the above



121
122
123
124
# File 'lib/rhoconnect/test_methods.rb', line 121

def test_schema
  @ss.process_query
  return @s.get_value(:schema)
end